@@ -22,7 +22,7 @@ class _ChannelPatterns:
     links = re.compile("q=https%3A%2F%2F(.*?)\"")
     upload_chunk = re.compile("gridVideoRenderer\":{(.*?)\"navigationEndpoint")
     upload_chunk_fl_1 = re.compile("simpleText\":\"Streamed")
-    upload_chunk_fl_2 = re.compile("{\"text\":\" watching\"}]")
+    upload_chunk_fl_2 = re.compile("default_live.")
     upcoming_check = re.compile("\"title\":\"Upcoming live streams\"")
     upcoming = re.compile("gridVideoRenderer\":{\"videoId\":\"(.*?)\"")
 
